cli

Function cli 

pub fn cli(rt: &Runtime<impl OptCtx>) -> !
Run a basic CLI for a given runtime

This is useful for providing to users to check their scripts or run their tests with the runtime that the host application provides.

This CLI provides the following subcommands:

  • doc: generate documentation
  • check: type check a script
  • test: run tests for a script
  • run: run a function of a script

This function exits the program and does not return.