pub struct Type { /* private fields */ }Expand description
A Roto type
This type will be cloned and dropped many times, so make sure to have
a cheap Clone and Drop implementations, for example an
Rc or an Arc.
Use one of the Type::clone or Type::copy constructors to construct
this type. Type::copy will generally be more performant than
Type::clone, so you should prefer that if the type implements Copy.
Usually, this type is not constructed directly, but created by the
library! macro
Implementations
Sourceimpl Type
impl Type
Sourcepub fn clone<T: Value + Clone + PartialEq>(
name: impl Into<Identifier>,
doc: impl AsRef<str>,
location: Location,
) -> Result<Self, RegistrationError>
pub fn clone<T: Value + Clone + PartialEq>( name: impl Into<Identifier>, doc: impl AsRef<str>, location: Location, ) -> Result<Self, RegistrationError>
A type implementing Clone.
The name must be a valid Rust identifier. The doc parameter is the
docstring that will be displayed in the documentation that Roto can
generate. The location is used for error reporting while registering
this item. You should generally pass roto::location!() to get a correct
value.
use roto::{Type, Val, location};
#[derive(Clone, PartialEq)]
struct Foo(i32);
Type::clone::<Val<Foo>>("Foo", "This is a foo!", location!()).unwrap();Sourcepub fn copy<T: Value + Copy + PartialEq>(
name: impl Into<Identifier>,
doc: impl AsRef<str>,
location: Location,
) -> Result<Self, RegistrationError>
pub fn copy<T: Value + Copy + PartialEq>( name: impl Into<Identifier>, doc: impl AsRef<str>, location: Location, ) -> Result<Self, RegistrationError>
A type implementing Copy.
The name must be a valid Roto identifier. The doc parameter is the
docstring that will be displayed in the documentation that Roto can
generate. The location is used for error reporting while registering
this item. You should generally pass roto::location!() to get a correct
value.
use roto::{Type, Val, location};
#[derive(Clone, Copy, PartialEq)]
struct Foo(i32);
Type::copy::<Val<Foo>>("Foo", "This is a foo!", location!()).unwrap();Trait Implementations