#[repr(transparent)]pub struct Val<T>(pub T);Expand description
A wrapper type that makes a registered type safe to pass to and from Roto.
Only types that implement the sealed Value trait can be passed to
Roto. Some primitive types implement this trait directly, but every other
type needs to be wrapped in Val. You should not wrap the primitives in
Val.
This type implements Deref and DerefMut to allow for easy access to
the inner value.
#[derive(Clone)]
struct Foo {
a: i32,
b: i32,
}
let rt = Runtime::from_lib(library! {
#[clone] type Foo = Val<Foo>;
}).unwrap();
// compile a script...
// Pass Foo to Roto wrapped in Val:
let f = pkg.get_function::<fn(Val<Foo>) -> ()>("main").unwrap();
f.call(Val(Foo { a: 1, b: 2 }));
// For Option and Verdict, wrap the inner type in Val
pkg.get_function::<fn(Option<Val<Foo>>) -> ()>("main").unwrap();
// Do not wrap types that already implement Value.
pkg.get_function::<fn(i32) -> ()>("main").unwrap();Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Ord> Ord for Val<T>
impl<T: Ord> Ord for Val<T>
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl<T: PartialOrd> PartialOrd for Val<T>
impl<T: PartialOrd> PartialOrd for Val<T>
Sourceimpl<T: 'static + Clone + PartialEq + Send + Sync> Value for Val<T>
impl<T: 'static + Clone + PartialEq + Send + Sync> Value for Val<T>
Sourcetype Transformed = Val<T>
type Transformed = Val<T>
Sourcefn transform(self) -> Self::Transformed
fn transform(self) -> Self::Transformed
Sourcefn untransform(transformed: Self::Transformed) -> Self
fn untransform(transformed: Self::Transformed) -> Self
Sourcefn as_param(transformed: &mut Self::Transformed) -> Self::AsParam
fn as_param(transformed: &mut Self::Transformed) -> Self::AsParam
Sourcefn to_value(param: Self::AsParam) -> Self::Transformed
fn to_value(param: Self::AsParam) -> Self::Transformed
Sourcefn from_ir_value(
mem: &mut Memory,
value: IrValue,
) -> Result<Self::AsParam, IrValueDoesNotMatchType>
fn from_ir_value( mem: &mut Memory, value: IrValue, ) -> Result<Self::AsParam, IrValueDoesNotMatchType>
Selfimpl<T: Copy> Copy for Val<T>
impl<T: Eq> Eq for Val<T>
impl<T> StructuralPartialEq for Val<T>